@@ -1,5 +1,5 @@
 import unittest
-from mw_python_sdk import list_datasets,list_all_dataset
+from mw_python_sdk import list_datasets,list_all_datasets
 import logging
 
 
@@ -14,7 +14,7 @@ class TestListDatasets(unittest.TestCase):
             dataset_iter = list_datasets("llama3chinese")
             for dataset in dataset_iter:
                 print(dataset)
-            datasets = list_all_dataset("llama3chinese")
+            datasets = list_all_datasets("llama3chinese")
             print(datasets)
         except Exception as err:
             print(f"An error occurred: {err}")
